==> servicecatalog-0.9.1-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/CloudFormationProvisionedProductResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-cloudformationprovisionedproduct.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:15:50.867Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.CloudFormationProvisionedProductResource")
public class CloudFormationProvisionedProductResource extends software.amazon.awscdk.Resource {
    protected CloudFormationProvisionedProductResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.CloudFormationProvisionedProductResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param parent the ``cdk.Construct`` this ``CloudFormationProvisionedProductResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CloudFormationProvisionedProductResource``
     */
    public CloudFormationProvisionedProductResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.servicecatalog.cloudformation.CloudFormationProvisionedProductResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param parent the ``cdk.Construct`` this ``CloudFormationProvisionedProductResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public CloudFormationProvisionedProductResource(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute CloudformationStackArn
     */
    public software.amazon.awscdk.services.servicecatalog.CloudFormationProvisionedProductCloudformationStackArn getCloudFormationProvisionedProductCloudformationStackArn() {
        return this.jsiiGet("cloudFormationProvisionedProductCloudformationStackArn", software.amazon.awscdk.services.servicecatalog.CloudFormationProvisionedProductCloudformationStackArn.class);
    }

    /**
     * @cloudformation_attribute RecordId
     */
    public software.amazon.awscdk.services.servicecatalog.CloudFormationProvisionedProductRecordId getCloudFormationProvisionedProductRecordId() {
        return this.jsiiGet("cloudFormationProvisionedProductRecordId", software.amazon.awscdk.services.servicecatalog.CloudFormationProvisionedProductRecordId.class);
    }

    public software.amazon.awscdk.services.servicecatalog.CloudFormationProvisionedProductId getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.servicecatalog.CloudFormationProvisionedProductId.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html
     */
    public static interface ProvisioningParameterProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        java.lang.Object getKey();
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final java.lang.String value);
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final software.amazon.awscdk.CloudFormationToken value);
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        java.lang.Object getValue();
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final java.lang.String value);
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link ProvisioningParameterProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ProvisioningParameterProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.Object _key;
            @javax.annotation.Nullable
            private java.lang.Object _value;

            /**
             * Sets the value of Key
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Key
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ProvisioningParameterProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ProvisioningParameterProperty build() {
                return new ProvisioningParameterProperty() {
                    @javax.annotation.Nullable
                    private java.lang.Object $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.Object $value = _value;

                    @Override
                    public java.lang.Object getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.cloudformation.CloudFormationProvisionedProductResource.ProvisioningParameterProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getKey() {
                return this.jsiiGet("key", java.lang.Object.class);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("value", value);
            }
        }
    }
}

==> servicecatalog-0.9.2-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/CloudFormationProvisionedProductResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-cloudformationprovisionedproduct.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-20T13:02:33.025Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.CloudFormationProvisionedProductResource")
public class CloudFormationProvisionedProductResource extends software.amazon.awscdk.Resource {
    protected CloudFormationProvisionedProductResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.CloudFormationProvisionedProductResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param parent the ``cdk.Construct`` this ``CloudFormationProvisionedProductResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CloudFormationProvisionedProductResource``
     */
    public CloudFormationProvisionedProductResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.servicecatalog.cloudformation.CloudFormationProvisionedProductResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param parent the ``cdk.Construct`` this ``CloudFormationProvisionedProductResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public CloudFormationProvisionedProductResource(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute CloudformationStackArn
     */
    public java.lang.String getCloudFormationProvisionedProductCloudformationStackArn() {
        return this.jsiiGet("cloudFormationProvisionedProductCloudformationStackArn", java.lang.String.class);
    }

    public java.lang.String getCloudFormationProvisionedProductId() {
        return this.jsiiGet("cloudFormationProvisionedProductId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute RecordId
     */
    public java.lang.String getCloudFormationProvisionedProductRecordId() {
        return this.jsiiGet("cloudFormationProvisionedProductRecordId", java.lang.String.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html
     */
    public static interface ProvisioningParameterProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        java.lang.Object getKey();
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final java.lang.String value);
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final software.amazon.awscdk.CloudFormationToken value);
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        java.lang.Object getValue();
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final java.lang.String value);
        /**
         * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link ProvisioningParameterProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ProvisioningParameterProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.Object _key;
            @javax.annotation.Nullable
            private java.lang.Object _value;

            /**
             * Sets the value of Key
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Key
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ProvisioningParameterProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ProvisioningParameterProperty build() {
                return new ProvisioningParameterProperty() {
                    @javax.annotation.Nullable
                    private java.lang.Object $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.Object $value = _value;

                    @Override
                    public java.lang.Object getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.cloudformation.CloudFormationProvisionedProductResource.ProvisioningParameterProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getKey() {
                return this.jsiiGet("key", java.lang.Object.class);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }

            /**
             * ``CloudFormationProvisionedProductResource.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("value", value);
            }
        }
    }
}
